"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _actionTypes = require("./actionTypes");

var URL = 'https://alergia-server-alergia.7e14.starter-us-west-2.openshiftapps.com/';

var successRequest = function successRequest(sender, data) {
  return {
    type: _actionTypes.REQUEST_SUCCESS,
    sender: sender,
    data: data
  };
};

var failureRequest = function failureRequest(sender, error) {
  return {
    type: _actionTypes.REQUEST_FAILURE,
    sender: sender,
    error: error
  };
};

var sendRequest = function sendRequest(sender) {
  return {
    type: _actionTypes.REQUEST_SENT,
    sender: sender
  };
};

var cleanRequest = function cleanRequest(sender) {
  return {
    type: _actionTypes.REQUEST_CLEAN,
    sender: sender
  };
};

var makeRequest = function makeRequest(url, sender, body) {
  var method = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'POST';
  var onSuccess = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : undefined;
  return function (dispatch) {
    dispatch(sendRequest(sender));
    return fetch(url, {
      method: method,
      body: JSON.stringify(body),
      credentials: 'include',
      mode: 'cors',
      headers: new Headers({
        Accept: 'application/json',
        'Content-Type': 'application/json'
      })
    }).then(function (response) {
      if (response.ok) {
        response.json().then(function (json) {
          var error = json.error,
              result = json.result;
          if (error) dispatch(failureRequest(sender, error));else {
            dispatch(successRequest(sender, result));
            if (onSuccess) onSuccess();
          }
        });
      } else {
        dispatch(failureRequest(sender, 'Network response was not ok.'));
      }
    }).catch(function (error) {
      dispatch(failureRequest(sender, error.message));
    });
  };
};

var _default = {
  sendRequest: sendRequest,
  successRequest: successRequest,
  failureRequest: failureRequest,
  makeRequest: makeRequest,
  cleanRequest: cleanRequest
};
exports.default = _default;